@@ -177,6 +177,23 @@ pub fn ewasm_main(attr: TokenStream, item: TokenStream) -> TokenStream {
                 }
             }
         },
+        "rusty" if Some("EwasmAny".to_string()) == output_type  => quote! {
+            #[cfg(target_arch = "wasm32")]
+            use sewup::bincode;
+            #[cfg(target_arch = "wasm32")]
+            use sewup::ewasm_api::finish_data;
+            #[cfg(all(not(target_arch = "wasm32"), not(test)))]
+            pub fn main() {}
+            #[cfg(target_arch = "wasm32")]
+            #[cfg(not(any(feature = "constructor", feature = "constructor-test")))]
+            #[no_mangle]
+            pub fn main() {
+                #input
+                let r = #name().map(|any| any.bin);
+                let bin = bincode::serialize(&r).expect("The resuslt of `ewasm_main` should be serializable");
+                finish_data(&bin);
+            }
+        },
 
         // Return all result structure
         // This is for a scenario that you are using a rust client to operation the contract
@@ -321,10 +338,10 @@ pub fn ewasm_fn(attr: TokenStream, item: TokenStream) -> TokenStream {
 #[proc_macro_error]
 #[proc_macro_attribute]
 pub fn ewasm_constructor(_attr: TokenStream, item: TokenStream) -> TokenStream {
-    let input = syn::parse_macro_input!(item as syn::ItemFn);
-    let name = &input.sig.ident;
-    if *name != "constructor" {
-        abort!(input.sig.ident, "please name the function as `constructor`");
+    let mut input = syn::parse_macro_input!(item as syn::ItemFn);
+    let default_name = Ident::new("__constructor", Span::call_site());
+    if input.sig.ident != "__constructor" {
+        input.sig.ident = default_name;
     }
     let result = quote! {
         #[cfg(target_arch = "wasm32")]
@@ -336,7 +353,7 @@ pub fn ewasm_constructor(_attr: TokenStream, item: TokenStream) -> TokenStream {
         #[cfg(feature = "constructor-test")]
         #[no_mangle]
         pub fn main() {
-            #name();
+            __constructor();
         }
     };
     result.into()
@@ -615,7 +632,7 @@ pub fn ewasm_input_from(item: TokenStream) -> TokenStream {
 pub fn ewasm_output_from(item: TokenStream) -> TokenStream {
     format!(
         r#"sewup::bincode::serialize(&{}).expect("fail to serialize in `ewasm_output_from`")"#,
-        item.to_string(),
+        item,
     )
     .parse()
     .unwrap()
@@ -710,7 +727,7 @@ pub fn derive_value(item: TokenStream) -> TokenStream {
 ///
 /// you can use `ewasm_output_from!` to get the exactly input/output binary of the protol, for
 /// example:
-/// ```
+/// ```compile_fail
 /// let handler_input = person::protocol(person);
 /// ewasm_output_from!(handler_input)
 /// ```
@@ -800,6 +817,7 @@ pub fn derive_table(item: TokenStream) -> TokenStream {
     let mut output = quote!(
         impl sewup::rdb::traits::Record for #struct_name {}
 
+        #[cfg_attr(any(feature = "debug", test), derive(Debug))]
         #[derive(Clone, sewup::Serialize, sewup::Deserialize)]
         pub struct #protocol_name {
             pub select_fields: Option<std::collections::HashSet::<String>>,
@@ -889,6 +907,7 @@ pub fn derive_table(item: TokenStream) -> TokenStream {
             pub const DELETE_SIG: [u8; 4] = ewasm_fn_sig!(#struct_name::delete());
         }
 
+        #[cfg_attr(any(feature = "debug", test), derive(Debug))]
         #[derive(Default, Clone, sewup::Serialize, sewup::Deserialize)]
         pub struct #wrapper_name {
             #(pub #wrapper_field_names: #wrapper_field_types,)*
@@ -1482,15 +1501,15 @@ pub fn SizedString(item: TokenStream) -> TokenStream {
 #[proc_macro]
 pub fn ewasm_call_only_by(item: TokenStream) -> TokenStream {
     let input = item.to_string().replace(" ", "");
-    let output = if input.starts_with("\"") {
-        let addr = format!("{}", input.replace("\"", ""));
+    let output = if input.starts_with('"') {
+        let addr = input.replace("\"", "");
         quote! {
             if sewup::utils::caller() != sewup::types::Address::from_str(#addr)? {
                 return Err(sewup::errors::HandlerError::Unauthorized.into())
             }
         }
     } else {
-        let addr = Ident::new(&format!("{}", input), Span::call_site());
+        let addr = Ident::new(&input, Span::call_site());
         quote! {
             if sewup::utils::caller() != sewup::types::Address::from_str(#addr)? {
                 return Err(sewup::errors::HandlerError::Unauthorized.into())
